@@ -363,17 +363,16 @@ class Signature:
     if name in self.defaults:
       values = self.defaults[name].data
       if len(values) > 1:
-        return "Union[%s]" % ", ".join(_print(v) for v in values)
+        return "..."
       else:
-        return _print(values[0])
+        return abstract_utils.show_constant(values[0])
     else:
       return None
 
   def __repr__(self):
     args = ", ".join(self._yield_arguments())
     ret = self._print_annot("return")
-    return "def {name}({args}) -> {ret}".format(
-        name=self.name, args=args, ret=ret if ret else "Any")
+    return f"def {self.name}({args}) -> {ret if ret else 'Any'}"
 
   def get_first_arg(self, callargs):
     return callargs.get(self.param_names[0]) if self.param_names else None
@@ -902,8 +901,8 @@ def match_all_args(ctx, node, func, args):
           break
         else:
           raise AssertionError(
-              "Mismatched parameter %s not found in passed_args" %
-              arg_name) from e
+              f"Mismatched parameter {arg_name} not found in passed_args"
+          ) from e
       else:
         # This is not an InvalidParameters error.
         raise
