@@ -2,12 +2,14 @@
 
 import contextlib
 import errno
-import glob
 import os
 import shutil
-import tempfile
+import sys
 import textwrap
 
+from pytype.platform_utils import path_utils
+from pytype.platform_utils import tempfile as compatible_tempfile
+
 
 def recursive_glob(path):
   """Call recursive glob iff ** is in the pattern."""
@@ -16,13 +18,13 @@ def recursive_glob(path):
     return [path]
   elif "**" not in path:
     # Recursive glob isn't needed.
-    return glob.glob(path)
+    return path_utils.glob(path)
   else:
-    return glob.glob(path, recursive=True)
+    return path_utils.glob(path, recursive=True)
 
 
 def replace_extension(filename, new_extension):
-  name, _ = os.path.splitext(filename)
+  name, _ = path_utils.splitext(filename)
   if new_extension.startswith("."):
     return name + new_extension
   else:
@@ -42,21 +44,21 @@ class Tempdir:
   """Context handler for creating temporary directories."""
 
   def __enter__(self):
-    self.path = tempfile.mkdtemp()
+    self.path = compatible_tempfile.mkdtemp()
     return self
 
   def create_directory(self, filename):
     """Create a subdirectory in the temporary directory."""
-    path = os.path.join(self.path, filename)
+    path = path_utils.join(self.path, filename)
     makedirs(path)
     return path
 
   def create_file(self, filename, indented_data=None):
     """Create a file in the temporary directory. Dedents the data if needed."""
-    filedir, filename = os.path.split(filename)
+    filedir, filename = path_utils.split(filename)
     if filedir:
       self.create_directory(filedir)
-    path = os.path.join(self.path, filedir, filename)
+    path = path_utils.join(self.path, filedir, filename)
     if isinstance(indented_data, bytes):
       # This is binary data rather than text.
       mode = "wb"
@@ -70,7 +72,7 @@ class Tempdir:
     return path
 
   def delete_file(self, filename):
-    os.unlink(os.path.join(self.path, filename))
+    os.unlink(path_utils.join(self.path, filename))
 
   def __exit__(self, error_type, value, tb):
     shutil.rmtree(path=self.path)
@@ -78,7 +80,7 @@ class Tempdir:
 
   def __getitem__(self, filename):
     """Get the full path for an entry in this directory."""
-    return os.path.join(self.path, filename)
+    return path_utils.join(self.path, filename)
 
 
 @contextlib.contextmanager
@@ -97,7 +99,7 @@ def cd(path):
   if not path:
     yield
     return
-  curdir = os.getcwd()
+  curdir = path_utils.getcwd()
   os.chdir(path)
   try:
     yield
@@ -109,13 +111,13 @@ def is_pyi_directory_init(filename):
   """Checks if a pyi file is path/to/dir/__init__.pyi."""
   if filename is None:
     return False
-  return os.path.splitext(os.path.basename(filename))[0] == "__init__"
+  return path_utils.splitext(path_utils.basename(filename))[0] == "__init__"
 
 
 def expand_path(path, cwd=None):
   """Fully expand a path, optionally with an explicit cwd."""
 
-  expand = lambda path: os.path.realpath(os.path.expanduser(path))
+  expand = lambda path: path_utils.realpath(path_utils.expanduser(path))
   with cd(cwd):
     return expand(path)
 
@@ -149,9 +151,9 @@ def expand_source_files(filenames, cwd=None):
   """
   out = []
   for f in expand_globpaths(filenames.split(), cwd):
-    if os.path.isdir(f):
+    if path_utils.isdir(f):
       # If we have a directory, collect all the .py files within it.
-      out += recursive_glob(os.path.join(f, "**", "*.py"))
+      out += recursive_glob(path_utils.join(f, "**", "*.py"))
     elif f.endswith(".py"):
       out.append(f)
   return set(out)
@@ -164,3 +166,11 @@ def expand_pythonpath(pythonpath, cwd=None):
         (path.strip() for path in pythonpath.split(os.pathsep)), cwd)
   else:
     return []
+
+
+def replace_separator(path: str):
+  """replace `/` with `os.path.sep`, replace `:` with `os.pathsep`."""
+  if sys.platform == "win32":
+    return path.replace("/", os.path.sep).replace(":", os.pathsep)
+  else:
+    return path
