@@ -1,10 +1,10 @@
 """Tests for imports_map_loader.py."""
 
-import tempfile
 import textwrap
 
 from pytype import file_utils
 from pytype import imports_map_loader
+from pytype.platform_utils import tempfile as compatible_tempfile
 
 import unittest
 
@@ -14,8 +14,8 @@ class ImportMapLoaderTest(unittest.TestCase):
 
   def test_read_imports_info(self):
     """Test reading an imports_info file into ImportsInfo."""
-    with tempfile.NamedTemporaryFile() as fi:
-      fi.write(textwrap.dedent("""
+    with compatible_tempfile.NamedTemporaryFile() as fi:
+      fi.write(textwrap.dedent(file_utils.replace_separator("""
         a/b/__init__.py prefix/1/a/b/__init__.py~
         a/b/b.py prefix/1/a/b/b.py~suffix
         a/b/c.pyi prefix/1/a/b/c.pyi~
@@ -23,29 +23,36 @@ class ImportMapLoaderTest(unittest.TestCase):
         a/b/e.py 2/a/b/e1.py~
         a/b/e 2/a/b/e2.py~
         a/b/e 2/a/b/foo/#2.py~
-      """).encode("utf-8"))
+      """)).encode("utf-8"))
       fi.seek(0)  # ready for reading
+      expected = [
+          ("a/b/__init__", ["prefix/1/a/b/__init__.py~"]),
+          ("a/b/b", ["prefix/1/a/b/b.py~suffix"]),
+          ("a/b/c", ["prefix/1/a/b/c.pyi~"]),
+          ("a/b/d", ["prefix/1/a/b/d.py~"]),
+          ("a/b/e", ["2/a/b/foo/#2.py~", "2/a/b/e1.py~", "2/a/b/e2.py~"]),
+      ]
+      f = file_utils.replace_separator
+      expected = [(f(k), list(map(f, v))) for k, v in expected]
       self.assertCountEqual(
           imports_map_loader._read_imports_map(fi.name, open).items(),
-          [
-              ("a/b/__init__", ["prefix/1/a/b/__init__.py~"]),
-              ("a/b/b", ["prefix/1/a/b/b.py~suffix"]),
-              ("a/b/c", ["prefix/1/a/b/c.pyi~"]),
-              ("a/b/d", ["prefix/1/a/b/d.py~"]),
-              ("a/b/e", ["2/a/b/foo/#2.py~", "2/a/b/e1.py~", "2/a/b/e2.py~"]),
-          ])
+          expected
+      )
 
   def test_do_not_filter(self):
     with file_utils.Tempdir() as d:
-      d.create_file("a/b/c.pyi")
-      imports_info = f"a/b/c.pyi {d['a/b/c.pyi']}\n"
+      d.create_file(file_utils.replace_separator("a/b/c.pyi"))
+      imports_info = (f"{file_utils.replace_separator('a/b/c.pyi')} " +
+                      f"{d[file_utils.replace_separator('a/b/c.pyi')]}\n")
       d.create_file("imports_info", imports_info)
       imports_map = imports_map_loader.build_imports_map(d["imports_info"])
-      self.assertEqual(imports_map["a/b/c"], d["a/b/c.pyi"])
+      self.assertEqual(imports_map[file_utils.replace_separator("a/b/c")],
+                       d[file_utils.replace_separator("a/b/c.pyi")])
 
   def test_invalid_map_entry(self):
     with file_utils.Tempdir() as d:
-      imports_info = f"a/b/c.pyi {d['a/b/c.pyi']}\n"
+      imports_info = (f"{file_utils.replace_separator('a/b/c.pyi')}"
+                      f"{d[file_utils.replace_separator('a/b/c.pyi')]}\n")
       d.create_file("imports_info", imports_info)
       with self.assertRaises(ValueError):
         imports_map_loader.build_imports_map(d["imports_info"])
