@@ -5,7 +5,6 @@ import collections.abc
 import dataclasses
 import itertools
 import logging
-import os
 import re
 import reprlib
 from typing import Optional, Sequence, Union
@@ -19,6 +18,7 @@ from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
 from pytype.abstract import function
 from pytype.abstract import mixin
+from pytype.platform_utils import path_utils
 from pytype.pyc import opcodes
 from pytype.pytd import mro
 from pytype.pytd import pytd
@@ -115,6 +115,7 @@ class _NameErrorDetails(abc.ABC):
 class _NameInInnerClassErrorDetails(_NameErrorDetails):
 
   def __init__(self, attr, class_name):
+    super().__init__()
     self._attr = attr
     self._class_name = class_name
 
@@ -317,8 +318,9 @@ def get_name_error_details(
 
 def _module_name(frame):
   if frame.f_code.co_filename:
-    return ".".join(re.sub(
-        r"\.py$", "", frame.f_code.co_filename).split(os.sep)[-2:])
+    return ".".join(
+        re.sub(r"\.py$", "",
+               frame.f_code.co_filename).split(path_utils.sep)[-2:])
   else:
     return ""
 
@@ -715,6 +717,14 @@ def _call_binop_on_bindings(node, name, xval, yval, ctx):
 
 
 def _get_annotation(node, var, ctx):
+  """Extract an annotation from terms in `a | b | ...`."""
+  # Python does not support late annotations in | expressions
+  try:
+    abstract_utils.get_atomic_python_constant(var, str)
+  except abstract_utils.ConversionError:
+    pass
+  else:
+    return None
   with ctx.errorlog.checkpoint() as record:
     annot = ctx.annotation_utils.extract_annotation(
         node, var, "varname", ctx.vm.simple_stack())
@@ -724,11 +734,16 @@ def _get_annotation(node, var, ctx):
 
 
 def _maybe_union(node, x, y, ctx):
+  """Attempt to evaluate a '|' operation as a typing.Union."""
   x_annot = _get_annotation(node, x, ctx)
   y_annot = _get_annotation(node, y, ctx)
-  if x_annot is None or y_annot is None:
-    return None
   opts = [x_annot, y_annot]
+  if any(o is None for o in opts):
+    return None
+  if all(isinstance(o, abstract.AMBIGUOUS) for o in opts):
+    # It is ambiguous whether this is a typing.Union or a regular __or__
+    # operation. Returning unsolvable is safe either way.
+    return ctx.new_unsolvable(node)
   return abstract.Union(opts, ctx).to_variable(node)
 
 
@@ -838,6 +853,7 @@ def load_closure_cell(state, op, check_bindings, ctx):
   # See test_closures.ClosuresTest.test_undefined_var
   if check_bindings and not cell.bindings:
     ctx.errorlog.name_error(ctx.vm.frames, op.pretty_arg)
+    cell = ctx.new_unsolvable(state.node)
   visible_bindings = cell.Filter(state.node, strict=False)
   if len(visible_bindings) != len(cell.bindings):
     # We need to filter here because the closure will be analyzed outside of
